@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "sops" "0.1.8"
+(define-package "sops" "20251102.57"
   "SOPS encrypt and decrypt without leaving the editor."
   '((emacs "28.1"))
-  :url "https://github.com/djgoku/sops"
-  :commit "4c0eba238837b439ac23493e70255abb22653ac6"
-  :revdesc "4c0eba238837"
+  :url "http://github.com/djgoku/sops"
+  :commit "7cce0d6800eff1e9c21ab43fffe1918bcc006e7d"
+  :revdesc "7cce0d6800ef"
   :keywords '("convenience" "programming")
   :authors '(("Jonathan Carroll Otsuka" . "pitas.axioms0c@icloud.com"))
   :maintainers '(("Jonathan Carroll Otsuka" . "pitas.axioms0c@icloud.com")))
